==> mhu-lib-core-3.2.9-sources.jar: de/mhus/lib/core/strategy/SuccessfulMap.java <==
package de.mhus.lib.core.strategy;

import java.util.HashMap;
import java.util.Set;

/**
 * <p>SuccessfulMap class.</p>
 *
 * @author mikehummel
 * @version $Id: $Id
 * @since 3.2.9
 */
public class SuccessfulMap extends Successful {

	/**
	 * <p>Constructor for SuccessfulMap.</p>
	 *
	 * @param operation a {@link de.mhus.lib.core.strategy.Operation} object.
	 * @param msg a {@link java.lang.String} object.
	 */
	public SuccessfulMap(Operation operation, String msg) {
		super(operation, msg);
		setResult(new HashMap<>());
	}

	/**
	 * <p>Constructor for SuccessfulMap.</p>
	 *
	 * @param path a {@link java.lang.String} object.
	 * @param msg a {@link java.lang.String} object.
	 * @param rc a long.
	 */
	public SuccessfulMap(String path, String msg, long rc) {
		super(path, msg, rc, new HashMap<>());
	}

	/**
	 * <p>Constructor for SuccessfulMap.</p>
	 *
	 * @param path a {@link java.lang.String} object.
	 * @param msg a {@link java.lang.String} object.
	 * @param rc a long.
	 * @param keyValues a {@link java.lang.String} object.
	 */
	public SuccessfulMap(String path, String msg, long rc, String... keyValues) {
		super(path, msg, rc, keyValues);
	}

	/**
	 * <p>put.</p>
	 *
	 * @param key a {@link java.lang.String} object.
	 * @param value a {@link java.lang.Object} object.
	 */
	@SuppressWarnings("unchecked")
	public void put(String key, Object value) {
		((HashMap<String,Object>)getResult()).put(key, value);
	}
	
	/**
	 * <p>get.</p>
	 *
	 * @param key a {@link java.lang.String} object.
	 * @return a {@link java.lang.Object} object.
	 */
	@SuppressWarnings("unchecked")
	public Object get(String key) {
		return ((HashMap<String,Object>)getResult()).get(key);
	}
	
	/**
	 * <p>remove.</p>
	 *
	 * @param key a {@link java.lang.String} object.
	 */
	@SuppressWarnings("unchecked")
	public void remove(String key) {
		((HashMap<String,Object>)getResult()).remove(key);
	}

	/**
	 * <p>keySet.</p>
	 *
	 * @return a {@link java.util.Set} object.
	 */
	@SuppressWarnings("unchecked")
	public Set<String> keySet() {
		return ((HashMap<String,String>)getResult()).keySet();
	}
	
}

==> mhu-lib-core-3.6.1-sources.jar: de/mhus/lib/core/strategy/SuccessfulMap.java <==
/**
 * Copyright 2018 Mike Hummel
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.mhus.lib.core.strategy;

import java.util.HashMap;
import java.util.Set;

public class SuccessfulMap extends Successful {

	public SuccessfulMap(Operation operation, String msg) {
		super(operation, msg);
		setResult(new HashMap<>());
	}

	public SuccessfulMap(String path, String msg, long rc) {
		super(path, msg, rc, new HashMap<>());
	}

	public SuccessfulMap(String path, String msg, long rc, String... keyValues) {
		super(path, msg, rc, keyValues);
	}

	@SuppressWarnings("unchecked")
	public void put(String key, Object value) {
		((HashMap<String,Object>)getResult()).put(key, value);
	}
	
	@SuppressWarnings("unchecked")
	public Object get(String key) {
		return ((HashMap<String,Object>)getResult()).get(key);
	}
	
	@SuppressWarnings("unchecked")
	public void remove(String key) {
		((HashMap<String,Object>)getResult()).remove(key);
	}

	@SuppressWarnings("unchecked")
	public Set<String> keySet() {
		return ((HashMap<String,String>)getResult()).keySet();
	}

	@SuppressWarnings("unchecked")
	public int size() {
		return ((HashMap<String,String>)getResult()).size();
	}
	
}
